:root {
  --ifm-color-primary: #f5a623;
  --ifm-color-primary-dark: #e69510;
  --ifm-color-primary-darker: #d98d0f;
  --ifm-color-primary-darkest: #b3740c;
  --ifm-color-primary-light: #f6b03d;
  --ifm-color-primary-lighter: #f7b84e;
  --ifm-color-primary-lightest: #f9ca78;
  --ifm-font-family-base: 'Inter', system-ui, -apple-system, sans-serif;
  --ifm-code-font-size: 95%;
  --docusaurus-highlighted-code-line-bg: rgba(245, 166, 35, 0.1);
}

[data-theme='dark'] {
  --ifm-color-primary: #f5a623;
  --ifm-color-primary-dark: #e69510;
  --ifm-color-primary-darker: #d98d0f;
  --ifm-color-primary-darkest: #b3740c;
  --ifm-color-primary-light: #f6b03d;
  --ifm-color-primary-lighter: #f7b84e;
  --ifm-color-primary-lightest: #f9ca78;
  --ifm-background-color: #1a1a1a;
  --ifm-background-surface-color: #222222;
  --ifm-navbar-background-color: #111111;
  --ifm-footer-background-color: #111111;
  --docusaurus-highlighted-code-line-bg: rgba(245, 166, 35, 0.15);
}

/* ASCII art hero */
.hero-ascii {
  background: #0d0d0d;
  padding: 4rem 0 3rem;
  text-align: center;
  overflow-x: auto;
}

.hero-ascii pre {
  font-family: 'JetBrains Mono', 'Fira Code', 'Cascadia Code', 'Consolas', monospace;
  font-size: clamp(0.35rem, 1.1vw, 0.85rem);
  line-height: 1.15;
  color: #f5a623;
  margin: 0 auto;
  display: inline-block;
  text-align: left;
  white-space: pre;
  text-shadow: 0 0 8px rgba(245, 166, 35, 0.3);
}

.hero-tagline {
  font-family: 'JetBrains Mono', 'Fira Code', monospace;
  color: #8a8a8a;
  font-size: 1.1rem;
  margin-top: 1.5rem;
  letter-spacing: 0.02em;
}

.hero-tagline .cursor {
  display: inline-block;
  width: 0.6em;
  height: 1.1em;
  background: #f5a623;
  margin-left: 2px;
  vertical-align: text-bottom;
  animation: blink 1s step-end infinite;
}

@keyframes blink {
  50% { opacity: 0; }
}

/* Feature cards */
.features-section {
  background: #111111;
  padding: 4rem 2rem;
}

.features-grid {
  display: grid;
  grid-template-columns: repeat(auto-fit, minmax(280px, 1fr));
  gap: 1.5rem;
  max-width: 1100px;
  margin: 0 auto;
}

.feature-card {
  background: #1a1a1a;
  border: 1px solid #2a2a2a;
  border-radius: 8px;
  padding: 1.5rem;
  transition: border-color 0.2s ease, transform 0.2s ease;
}

.feature-card:hover {
  border-color: #f5a623;
  transform: translateY(-2px);
}

.feature-card h3 {
  color: #f5a623;
  font-family: 'JetBrains Mono', 'Fira Code', monospace;
  font-size: 1rem;
  margin-bottom: 0.5rem;
}

.feature-card p {
  color: #999;
  font-size: 0.9rem;
  line-height: 1.5;
  margin: 0;
}

/* CTA section */
.cta-section {
  background: #0d0d0d;
  padding: 3rem 2rem;
  text-align: center;
}

.cta-terminal {
  background: #1a1a1a;
  border: 1px solid #2a2a2a;
  border-radius: 8px;
  padding: 1.5rem 2rem;
  display: inline-block;
  max-width: 600px;
  width: 100%;
  text-align: left;
}

.cta-terminal .terminal-header {
  display: flex;
  gap: 6px;
  margin-bottom: 1rem;
}

.cta-terminal .terminal-dot {
  width: 10px;
  height: 10px;
  border-radius: 50%;
}

.cta-terminal .terminal-dot.red { background: #ff5f57; }
.cta-terminal .terminal-dot.yellow { background: #febc2e; }
.cta-terminal .terminal-dot.green { background: #28c840; }

.cta-terminal code {
  font-family: 'JetBrains Mono', 'Fira Code', monospace;
  color: #e0e0e0;
  font-size: 0.9rem;
  display: block;
  line-height: 1.8;
}

.cta-terminal code .prompt {
  color: #f5a623;
}

.cta-terminal code .comment {
  color: #555;
}

.cta-buttons {
  margin-top: 2rem;
  display: flex;
  gap: 1rem;
  justify-content: center;
  flex-wrap: wrap;
}

.cta-buttons a {
  display: inline-block;
  padding: 0.7rem 1.8rem;
  border-radius: 6px;
  font-family: 'JetBrains Mono', 'Fira Code', monospace;
  font-size: 0.9rem;
  text-decoration: none;
  transition: all 0.2s ease;
}

.cta-buttons a.primary {
  background: #f5a623;
  color: #0d0d0d;
  font-weight: 600;
}

.cta-buttons a.primary:hover {
  background: #f6b03d;
  transform: translateY(-1px);
}

.cta-buttons a.secondary {
  background: transparent;
  color: #f5a623;
  border: 1px solid #f5a623;
}

.cta-buttons a.secondary:hover {
  background: rgba(245, 166, 35, 0.1);
  transform: translateY(-1px);
}

/* Navbar tweaks */
.navbar {
  border-bottom: 1px solid #222;
}

.navbar__title {
  font-family: 'JetBrains Mono', 'Fira Code', monospace;
  font-weight: 700;
}

/* Footer tweaks */
.footer--dark {
  border-top: 1px solid #222;
}
